@@ -12,6 +12,7 @@ var npm = require('./npm.js')
 var git = require('./utils/git.js')
 var assert = require('assert')
 var lifecycle = require('./utils/lifecycle.js')
+var parseJSON = require('./utils/parse-json.js')
 
 version.usage = 'npm version [<newversion> | major | minor | patch | premajor | preminor | prepatch | prerelease]' +
                 '\n(run in package dir)\n' +
@@ -32,7 +33,7 @@ function version (args, silent, cb_) {
   fs.readFile(packagePath, function (er, data) {
     if (data) data = data.toString()
     try {
-      data = JSON.parse(data)
+      data = parseJSON(data)
     } catch (e) {
       er = e
       data = null
@@ -107,7 +108,7 @@ function updateShrinkwrap (newVersion, cb) {
 
     try {
       data = data.toString()
-      data = JSON.parse(data)
+      data = parseJSON(data)
     } catch (er) {
       log.error('version', 'Bad npm-shrinkwrap.json data')
       return cb(er)
@@ -180,13 +181,14 @@ function checkGit (localData, cb) {
 }
 
 function _commit (version, hasShrinkwrap, cb) {
+  var packagePath = path.join(npm.localPrefix, 'package.json')
   var options = { env: process.env }
   var message = npm.config.get('message').replace(/%s/g, version)
   var sign = npm.config.get('sign-git-tag')
   var flag = sign ? '-sm' : '-am'
   chain(
     [
-      git.chainableExec([ 'add', 'package.json' ], options),
+      git.chainableExec([ 'add', packagePath ], options),
       hasShrinkwrap && git.chainableExec([ 'add', 'npm-shrinkwrap.json' ], options),
       git.chainableExec([ 'commit', '-m', message ], options),
       git.chainableExec([ 'tag', npm.config.get('tag-version-prefix') + version, flag, message ], options)
